<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-urls?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// U
	'urls_description' => 'إدارة تنوعات عناوين URL ذات المعنى ام لا',
	'urls_slogan' => 'إدارة تنوعات عناوين URL ذات المعنى ام لا'
);

?>
